@@ -158,6 +158,17 @@ def sampled_from(elements):
     """
     values = check_sample(elements, "sampled_from")
     if not values:
+        if (
+            isinstance(elements, type)
+            and issubclass(elements, enum.Enum)
+            and vars(elements).get("__annotations__")
+        ):
+            # See https://github.com/HypothesisWorks/hypothesis/issues/2923
+            raise InvalidArgument(
+                f"Cannot sample from {elements.__module__}.{elements.__name__} "
+                "because it contains no elements.  It does however have annotations, "
+                "so maybe you tried to write an enum as if it was a dataclass?"
+            )
         raise InvalidArgument("Cannot sample from a length-zero sequence.")
     if len(values) == 1:
         return just(values[0])
@@ -385,13 +396,12 @@ def fixed_dictionaries(
     """Generates a dictionary of the same type as mapping with a fixed set of
     keys mapping to strategies. ``mapping`` must be a dict subclass.
 
-    Generated values have all keys present in mapping, with the
-    corresponding values drawn from mapping[key]. If mapping is an
-    instance of OrderedDict the keys will also be in the same order,
-    otherwise the order is arbitrary.
+    Generated values have all keys present in mapping, in iteration order,
+    with the corresponding values drawn from mapping[key].
 
     If ``optional`` is passed, the generated value *may or may not* contain each
     key from ``optional`` and a value drawn from the corresponding strategy.
+    Generated values may contain optional keys in an arbitrary order.
 
     Examples from this strategy shrink by shrinking each individual value in
     the generated dictionary, and omitting optional key-value pairs.
@@ -1433,7 +1443,7 @@ def complex_numbers(
     is an error to enable ``allow_nan``.  If ``max_magnitude`` is finite,
     it is an error to enable ``allow_infinity``.
 
-    The magnitude contraints are respected up to a relative error
+    The magnitude constraints are respected up to a relative error
     of (around) floating-point epsilon, due to implementation via
     the system ``sqrt`` function.
 
